#

    	measured_ingredients

    		[
    			{
    				"name": "Iron, Fe",
    				"measures": {
    					"mass + mass equivalents": {
    						"per package": {
    							"listed": [
    								"11.320",
    								"mg"
    							],
    							"grams": {
    								"scinote string": "1.1320e-2",
    								"decimal string": "0.011",
    								"fraction string": "283/25000"
    							}
    						}
    					}
    				}
    			}
    		]